@@ -7,6 +7,7 @@ from pathlib import Path
 from rmx import logger
 from rmx.helpers import find_project_root, parse_config
 from posixpath import expandvars
+from dotenv import dotenv_values
 
 from rmx.machine import RemoteConfig
 
@@ -143,6 +144,7 @@ def load_config(parsed):
                                 name=parsed.name,
                                 sweep=parsed.sweep,
                                 num_sequence=parsed.num_sequence,
+                                no_sync=parsed.no_sync,
                                 force=parsed.force)
 
     mount_dirs = pconfig.get('mount', [])
@@ -153,13 +155,14 @@ def load_config(parsed):
     if 'mount_from_host' in mconf:
         mount_from_host = mconf.get('mount_from_host', {})
 
-
+    # Load extra env vars from .env.secret
+    env = {**pconfig.get('environment', {}), **dotenv_values((proj_rootdir / ".env.secret").resolve())}
     project = Project(name,
                       proj_rootdir,
                       outdir=pconfig.get('outdir'),
                       exclude=pconfig.get('exclude', []),
                       startup=pconfig.get('startup', ""),
-                      env=pconfig.get('environment', {}),
+                      env=env,
                       mount_dirs=mount_dirs,
                       mount_from_host=mount_from_host)
 
@@ -210,7 +213,7 @@ def load_config(parsed):
 
     machine = Machine(remote_conf,
                       mode=mode,
-                      rmxdir=mconf.get('root_dir', REMOTE_ROOT_DIR),
+                      rmxdir=mconf.get('root_dir', f'{REMOTE_ROOT_DIR}/{remote_conf.user}'),
                       env=mconf.get('environment'),
                       docker_conf=docker,
                       sing_conf=sing,
