@@ -59,6 +59,11 @@ def _get_parser() -> ArgumentParser:
         action="store_true",
         help="X11 forwarding",
     )
+    parser.add_argument(
+        "--no-sync",
+        action="store_true",
+        help="Do not perform rsync. This means your local files will not be synced with remote server.",
+    )
     parser.add_argument(
         "-n",
         "--num-sequence",
@@ -118,12 +123,14 @@ def handler(project, machine: Machine, runtime_options):
     logger.info(f'handling command for {__file__}')
     logger.info(f'options: {runtime_options}')
 
+    if runtime_options.no_sync:
+        logger.warn('--no-sync option is True, local files will not be synced.')
+
     # Sync code first
-    _sync_code(project, machine, runtime_options)
+    if not runtime_options.no_sync:
+        _sync_code(project, machine, runtime_options)
 
-    # TODO: Collect all envvars!!
     env = {**project.env, **machine.env}
-
     rmxdirs = machine.get_rmxdirs(project.name)
     startup = '&&'.join([e for e in [machine.startup, project.startup] if e.strip() != ""])
     if machine.mode == 'ssh':
@@ -172,9 +179,13 @@ def handler(project, machine: Machine, runtime_options):
         # remote_outdir = remote_rootdir / 'output'
         # remote_mountdir = remote_rootdir / 'mount'
         docker_rmxdirs = machine.docker.get_rmxdirs(project.name)
-        mounts = [Mount(target=docker_rmxdirs.codedir, source=rmxdirs.codedir, type='bind'),
-                   Mount(target=docker_rmxdirs.outdir, source=rmxdirs.outdir, type='bind'),
-                   Mount(target=docker_rmxdirs.mountdir, source=rmxdirs.mountdir, type='bind')]
+
+        if not runtime_options.no_sync:
+            mounts = [Mount(target=docker_rmxdirs.codedir, source=rmxdirs.codedir, type='bind'),
+                    Mount(target=docker_rmxdirs.outdir, source=rmxdirs.outdir, type='bind'),
+                    Mount(target=docker_rmxdirs.mountdir, source=rmxdirs.mountdir, type='bind')]
+        else:
+            mounts = []
         mounts += [Mount(target=tgt, source=src, type='bind') for src, tgt in project.mount_from_host.items()]
 
 
@@ -243,9 +254,10 @@ def handler(project, machine: Machine, runtime_options):
 
             # Bind
             bind = '-B {source}:{target}'
-            options += [bind.format(target=sing_rmxdirs.codedir, source=rmxdirs.codedir),
-                      bind.format(target=sing_rmxdirs.outdir, source=rmxdirs.outdir),
-                      bind.format(target=sing_rmxdirs.mountdir, source=rmxdirs.mountdir)]
+            if not runtime_options.no_sync:
+                options += [bind.format(target=sing_rmxdirs.codedir, source=rmxdirs.codedir),
+                        bind.format(target=sing_rmxdirs.outdir, source=rmxdirs.outdir),
+                        bind.format(target=sing_rmxdirs.mountdir, source=rmxdirs.mountdir)]
             options += [bind.format(target=tgt, source=src) for src, tgt in project.mount_from_host.items()]
 
             # Overlay
@@ -284,7 +296,8 @@ def handler(project, machine: Machine, runtime_options):
                               env=env, dry_run=run_opt.dry_run)
 
     # Sync output files
-    _sync_output(project, machine, runtime_options)
+    if not runtime_options.no_sync:
+        _sync_output(project, machine, runtime_options)
 
 name = 'run'
 description = 'run command'
